==> okta__okta-auth-js-6.5.1.jar: META-INF/resources/webjars/okta__okta-auth-js/6.5.1/cjs/idx/register.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");

exports.register = register;

var _includes = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/includes"));

var _run = require("./run");

var _transactionMeta = require("./transactionMeta");

var _startTransaction = require("./startTransaction");

var _errors = require("../errors");

var _types = require("../types");

/*!
 * Copyright (c) 2015-present, Okta, Inc. and/or its affiliates. All rights reserved.
 * The Okta software accompanied by this notice is provided pursuant to the Apache License, Version 2.0 (the "License.")
 *
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0.
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * 
 * See the License for the specific language governing permissions and limitations under the License.
 */
async function register(authClient, options = {}) {
  // Only check at the beginning of the transaction
  if (!(0, _transactionMeta.hasSavedInteractionHandle)(authClient)) {
    const {
      enabledFeatures,
      availableSteps
    } = await (0, _startTransaction.startTransaction)(authClient, { ...options,
      flow: 'register',
      autoRemediate: false
    });

    if (!options.activationToken && enabledFeatures && !(0, _includes.default)(enabledFeatures).call(enabledFeatures, _types.IdxFeature.REGISTRATION)) {
      const error = new _errors.AuthSdkError('Registration is not supported based on your current org configuration.');
      throw error; // return { status: IdxStatus.FAILURE, error } as unknown as IdxTransaction; // TODO: wny not just throw the error?
    }

    if (options.activationToken && availableSteps !== null && availableSteps !== void 0 && availableSteps.some(({
      name
    }) => name === 'identify')) {
      const error = new _errors.AuthSdkError('activationToken is not supported based on your current org configuration.');
      throw error; // return { status: IdxStatus.FAILURE, error } as unknown as IdxTransaction; // TODO: wny not just throw the error?
    }
  }

  return (0, _run.run)(authClient, { ...options,
    flow: 'register'
  });
}
//# sourceMappingURL=register.js.map

==> okta__okta-auth-js-7.0.2.jar: META-INF/resources/webjars/okta__okta-auth-js/7.0.2/cjs/idx/register.js <==
"use strict";

exports.register = register;

var _run = require("./run");

var _transactionMeta = require("./transactionMeta");

var _startTransaction = require("./startTransaction");

var _errors = require("../errors");

var _types = require("./types");

/*!
 * Copyright (c) 2015-present, Okta, Inc. and/or its affiliates. All rights reserved.
 * The Okta software accompanied by this notice is provided pursuant to the Apache License, Version 2.0 (the "License.")
 *
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0.
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * 
 * See the License for the specific language governing permissions and limitations under the License.
 */
async function register(authClient, options = {}) {
  // Only check at the beginning of the transaction
  if (!(0, _transactionMeta.hasSavedInteractionHandle)(authClient)) {
    const {
      enabledFeatures
    } = await (0, _startTransaction.startTransaction)(authClient, { ...options,
      flow: 'register',
      autoRemediate: false
    });

    if (!options.activationToken && enabledFeatures && !enabledFeatures.includes(_types.IdxFeature.REGISTRATION)) {
      throw new _errors.AuthSdkError('Registration is not supported based on your current org configuration.');
    }
  }

  return (0, _run.run)(authClient, { ...options,
    flow: 'register'
  });
}
//# sourceMappingURL=register.js.map
